"Fixer" functions
=================

.. automodule:: ftfy.fixes
   :members: decode_escapes, decode_inconsistent_utf8, fix_c1_controls,
             fix_character_width, fix_latin_ligatures, fix_line_breaks,
             fix_surrogates, remove_control_chars, remove_terminal_escapes,
             replace_lossy_sequences, restore_byte_a0, uncurl_quotes,
             unescape_html
